SystemOrganization addCategory: #ApplicationBase!

!True methodsFor: '*ApplicationBase-debugging' stamp: 'mu 3/27/2006 16:46'!
haltIfTrue
	AbDebug current haltIfTrue: [self]! !

!False methodsFor: '*ApplicationBase-debugging' stamp: 'mu 3/27/2006 16:46'!
haltIfFalse
	AbDebug current haltIfFalse: [self]! !

Object subclass: #AbDebug
	instanceVariableNames: ''
	classVariableNames: 'CurrentDebug StoredTemporaryData'
	poolDictionaries: ''
	category: 'ApplicationBase'!

AbDebug class
	instanceVariableNames: 'isDebugging'!

!AbDebug class methodsFor: 'transcript' stamp: 'minami 3/29/2006 15:49'!
cr
	self isDebugging ifTrue: [Transcript cr]! !

!AbDebug class methodsFor: 'transcript' stamp: 'mu 3/27/2006 15:55'!
crShow: aString
	self isDebugging ifTrue: [Transcript cr; show: aString]! !

!AbDebug class methodsFor: 'accessing' stamp: 'mu 3/27/2006 16:46'!
current
	CurrentDebug ifNil: [CurrentDebug _ self].
	^CurrentDebug! !

!AbDebug class methodsFor: 'accessing' stamp: 'mu 3/27/2006 16:46'!
current: aDebugClass
	CurrentDebug _ aDebugClass! !

!AbDebug class methodsFor: 'displaying' stamp: 'mu 3/27/2006 15:55'!
display: anObject at: point 
	self isDebugging
		ifTrue: [anObject asString displayAt: point]! !

!AbDebug class methodsFor: 'logging' stamp: 'minami 3/23/2006 19:24'!
dump: anObject 
	|  imageName filename |
	imageName _ (Smalltalk imageName findTokens: FileDirectory slash) last.
	filename _ self name, '(', imageName, ')', '.log'.
	self dump: anObject to: filename.! !

!AbDebug class methodsFor: 'logging' stamp: 'minami 3/23/2006 19:24'!
dump: anObject to: filename 
	| file |
	file _ FileStream fileNamed: filename asString.
	file isNil
		ifTrue: [self crShow: 'File open failed in Error Logging:' , anObject printString.
			^ self].
	file setToEnd.
	file cr; nextPutAll: '### Dumping Object is... ###'.
	file cr; nextPutAll: TimeStamp current printString.
	anObject isCollection
		ifTrue: [file cr; nextPutAll: '#CollectionObject: ' , anObject name , '('.
			anObject
				do: [:each | file cr; nextPutAll: '#Object: ' , each printString].
			file cr; nextPutAll: ')']
		ifFalse: [file cr; nextPutAll: '#Object: ' , anObject printString].
	file close! !

!AbDebug class methodsFor: 'logging' stamp: 'mu 3/27/2006 15:55'!
forgetFor: sender 
	^ self isDebugging
		ifTrue: [self storedTemporaryData
				removeKey: sender
				ifAbsent: []]! !

!AbDebug class methodsFor: 'halting' stamp: 'mu 3/27/2006 15:55'!
halt
	self isDebugging ifTrue: [Halt signal].

	! !

!AbDebug class methodsFor: 'halting' stamp: 'mu 10/12/2006 10:51'!
haltIf: aBlock
	self isDebugging ifFalse: [^ self].

	aBlock value ifTrue: [self halt].! !

!AbDebug class methodsFor: 'halting' stamp: 'mu 10/12/2006 11:34'!
haltOnlyOnce
	self isDebugging ifTrue: [
		self haltOnlyOnce
	].

	! !

!AbDebug class methodsFor: 'class initialization' stamp: 'mu 6/20/2006 11:10'!
initialize
"
	AbDebug initialize
"
	isDebugging := false.
	CurrentDebug _ self.

	self initStoredTemporaryData..

	Smalltalk addToShutDownList: self
	! !

!AbDebug class methodsFor: 'class initialization' stamp: 'mu 6/20/2006 11:04'!
initStoredTemporaryData

	StoredTemporaryData _ Dictionary new! !

!AbDebug class methodsFor: 'accessing' stamp: 'mu 3/27/2006 15:54'!
isDebugging
	^ isDebugging == true! !

!AbDebug class methodsFor: 'accessing' stamp: 'mu 3/27/2006 15:54'!
isDebugging: aBoolean
	isDebugging := (aBoolean == true)! !

!AbDebug class methodsFor: 'logging' stamp: 'minami 3/23/2006 19:30'!
log: anError 
	|  imageName filename |
	imageName _ (Smalltalk imageName findTokens: FileDirectory slash) last.
	filename _ self name, '(', imageName, ')', '.log'.
	self log: anError to: filename.! !

!AbDebug class methodsFor: 'logging' stamp: 'mu 3/27/2006 15:55'!
log: anError to: filename
	| ex file ctx stack |
	self isDebugging ifFalse: [^nil].
	ex _ anError.
	file _ FileStream fileNamed: filename asString.
	file isNil
		ifTrue: [self crShow: 'File open failed in Error Logging:', ex description.
			^ self].
	file setToEnd.
	file cr; nextPutAll: '### Original Error is... ###'.
	file cr; nextPutAll: TimeStamp current printString.
	file cr; nextPutAll: '#Receiver: ' , ex receiver asString.
	file cr; nextPutAll: '#Description: ' , ex description asString.
	ctx _ ex signalerContext.
	stack _ ctx isNil
				ifTrue: ['']
				ifFalse: [ctx shortStack].
	file cr; nextPutAll: '#Stack:'.
	file cr; cr; nextPutAll: stack asString.
	file close! !

!AbDebug class methodsFor: 'class initialization' stamp: 'minami 3/23/2006 19:29'!
obsolete
	Smalltalk removeFromShutDownList: self.
	super obsolete! !

!AbDebug class methodsFor: 'halting' stamp: 'mu 10/12/2006 11:27'!
rearmOneShot
	self isDebugging ifTrue: [
		self rearmOneShot
	].

	! !

!AbDebug class methodsFor: 'logging' stamp: 'minami 3/23/2006 19:31'!
remember: anObject
	self remember: anObject for: thisContext sender printString! !

!AbDebug class methodsFor: 'logging' stamp: 'mu 3/27/2006 15:55'!
remember: anObject for: sender 
	self isDebugging
		ifTrue: [| entries | 
			entries _ self storedTemporaryData
						at: sender
						ifAbsentPut: [OrderedCollection new].
			entries add: {Time dateAndTimeNow. anObject}]! !

!AbDebug class methodsFor: 'logging' stamp: 'mu 3/27/2006 15:55'!
retrieveFor: sender 
	self isDebugging
		ifTrue: [| entries | 
			entries _ self storedTemporaryData
						at: sender
						ifAbsent: [].
			^ entries].
	^nil! !

!AbDebug class methodsFor: 'transcript' stamp: 'mu 3/27/2006 15:55'!
show: aString
	self isDebugging ifTrue: [Transcript show: aString]! !

!AbDebug class methodsFor: 'system startup' stamp: 'mu 6/20/2006 11:09'!
shutDown
	self initStoredTemporaryData! !

!AbDebug class methodsFor: 'accessing' stamp: 'mu 6/20/2006 11:03'!
storedTemporaryData
	StoredTemporaryData ifNil: [StoredTemporaryData _ Dictionary new].
	^ StoredTemporaryData! !

Object subclass: #AbInitializer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ApplicationBase'!

!AbInitializer class methodsFor: 'class initialization' stamp: 'minami 3/15/2006 20:08'!
initialize
	"AbInitializer initialize"

	Smalltalk addToStartUpList: self.
	Smalltalk addToShutDownList: self! !

!AbInitializer class methodsFor: 'class initialization' stamp: 'minami 3/15/2006 20:08'!
obsolete
	"AbInitializer obsolete"

	Smalltalk removeFromStartUpList: self.
	Smalltalk removeFromShutDownList: self.
! !

!AbInitializer class methodsFor: 'system startup' stamp: 'minami 3/23/2006 18:54'!
shutDown: quitting
	self systemShutDown: quitting! !

!AbInitializer class methodsFor: 'system startup' stamp: 'minami 3/23/2006 18:54'!
startUp: resuming
	self systemStartUp: resuming! !

!AbInitializer class methodsFor: 'private' stamp: 'minami 3/23/2006 18:51'!
systemShutDown: quitting
	self allSubclassesDo: [:sub | sub systemShutDown: quitting].! !

!AbInitializer class methodsFor: 'private' stamp: 'mu 4/2/2006 17:11'!
systemStartUp: resuming
	AbUtil initialize.
	self allSubclassesDo: [:sub | sub systemStartUp: resuming].! !

Object subclass: #AbSettings
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ApplicationBase'!

AbSettings class
	instanceVariableNames: 'settingsDict'!

!AbSettings class methodsFor: 'setting access' stamp: 'mu 3/27/2006 17:03'!
at: key ifAbsentPut: aBlock 
	^ self settingsDict
		at: key
		ifAbsentPut: [self changed: key.
			aBlock value]! !

!AbSettings class methodsFor: 'setting access' stamp: 'mu 3/27/2006 17:22'!
at: key put: value 
	self changed: key.
	^ self settingsDict at: key put: value! !

!AbSettings class methodsFor: 'read/write' stamp: 'minami 3/15/2006 20:11'!
configure
	self preConfiguration.
	self readConfigurationFrom: self defaultConfigurationFilename.
	self postConfiguration! !

!AbSettings class methodsFor: 'defaults' stamp: 'minami 3/15/2006 20:11'!
defaultConfigurationFilename
	^ (self name , '.ini') copy! !

!AbSettings class methodsFor: 'class initialization' stamp: 'minami 3/15/2006 20:10'!
initialize
	settingsDict := nil! !

!AbSettings class methodsFor: 'private' stamp: 'minami 3/15/2006 20:12'!
postConfiguration
	^ self! !

!AbSettings class methodsFor: 'private' stamp: 'minami 3/15/2006 20:12'!
preConfiguration
	self initialize! !

!AbSettings class methodsFor: 'read/write' stamp: 'mu 3/27/2006 17:40'!
readConfigurationFrom: filename 
	| loadedSettings |
	loadedSettings := AbUtil readConfigurationFrom: filename.
	loadedSettings
		keysAndValuesDo: [:key :value | [self perform: (key , ':') asSymbol with: value]
				on: Error
				do: [:ex | Transcript cr; show: '##Setting load failed:' , key]]! !

!AbSettings class methodsFor: 'private' stamp: 'minami 3/15/2006 20:11'!
settingsDict
	settingsDict ifNil: [settingsDict := IdentityDictionary new].
	^ settingsDict! !

!AbSettings class methodsFor: 'private' stamp: 'minami 3/15/2006 20:12'!
settingsDict: anIdentityDictionary 
	settingsDict := anIdentityDictionary! !

Object subclass: #AbUtil
	instanceVariableNames: ''
	classVariableNames: 'LocalAddressString'
	poolDictionaries: ''
	category: 'ApplicationBase'!

!AbUtil class methodsFor: 'definition' stamp: 'minami 4/19/2006 17:31'!
addClassVariableNamed: newVariableName to: targetClassName

	| targetClass iVarNames cVarNames |
	targetClass := Smalltalk at: targetClassName asSymbol ifAbsent: [self error: 'No such a Class'].
	(targetClass classVarNames includes: newVariableName) ifTrue: [^ self]. "newVariableName is already defined".

	iVarNames := targetClass instVarNames.
	cVarNames := targetClass classVarNames , {newVariableName}.
	
	targetClass superclass 
		perform: #subclass:instanceVariableNames:classVariableNames:poolDictionaries:category:
		withArguments: {
			targetClass name.
			String streamContents:[:s | iVarNames do: [:varName | s nextPutAll: varName; space]].
			String streamContents:[:s | cVarNames do: [:varName | s nextPutAll: varName; space]].
			targetClass sharedPoolsString.
			targetClass category.
		}.! !

!AbUtil class methodsFor: 'definition' stamp: 'minami 4/19/2006 17:31'!
addInstanceVariableNamed: newVariableName to: targetClassName
	
	| targetClass iVarNames cVarNames |
	targetClass := Smalltalk at: targetClassName asSymbol ifAbsent: [self error: 'No such a Class'].
	(targetClass instVarNames includes: newVariableName) ifTrue: [^ self]. "newVariableName is already defined".

	iVarNames := targetClass instVarNames , {newVariableName}.
	cVarNames := targetClass classVarNames.
	
	targetClass superclass 
		perform: #subclass:instanceVariableNames:classVariableNames:poolDictionaries:category:
		withArguments: {
			targetClass name.
			String streamContents:[:s | iVarNames do: [:varName | s nextPutAll: varName; space]].
			String streamContents:[:s | cVarNames do: [:varName | s nextPutAll: varName; space]].
			''.
			targetClass category.
		}.! !

!AbUtil class methodsFor: 'networing' stamp: 'mu 11/23/2006 00:33'!
basicLocalAddressString
	"AbUtil basicLocalAddressString"

	| localAddressString |
	localAddressString _ NetNameResolver localAddressString.
	localAddressString = '127.0.0.1' ifFalse: [^localAddressString].

	(self isDarwinMac or: [self isUnix not]) ifTrue: [^localAddressString].

	"For classic unix vm which always returns local address string as 127.0.0.1"
	^self isOsProcessInstalled 
		ifTrue: [self localAddressStringByIfConfig]
		ifFalse: [self readLocalAddressString].
	
! !

!AbUtil class methodsFor: 'serialize/deserialize' stamp: 'minami 3/15/2006 20:04'!
byteArrayFromObject: anObject 
"
	AbUtil byteArrayFromObject: #(1 3 5) 
		>> a ByteArray(8 0 0 0 3 4 0 0 0 1 4 0 0 0 3 4 0 0 0 5)
"

	| refStream |
	refStream := ReferenceStream on: (RWBinaryOrTextStream on: (ByteArray new: 4000)).
	refStream nextPut: anObject.
	^ refStream byteStream contents.! !

!AbUtil class methodsFor: 'networing' stamp: 'mu 11/23/2006 00:28'!
extractAddressStringFrom: rawString 

	"Just read the first ipv4 address in rawString - its not so good, but works in most cases"

	| tokens address |
	tokens := rawString asString findTokens: Character tab asString , Character space asString , Character cr asString , Character lf asString , ':,'.
	address := tokens
				detect: [:each | (NetNameResolver addressFromString: each) notNil]
				ifNone: [''].
	^ address! !

!AbUtil class methodsFor: 'unix process' stamp: 'mu 4/1/2006 23:14'!
forkUnixCommand: aString args: stringArgs 
	"self forkUnixCommand: '/sbin/ifconfig' args: #()"

	"If OSProcess module is not available in VM, just return nil"

	| tmpFileName out err desc args proc |
	tmpFileName := 'SqueakCommand:' , UUID new asString.
	[out := FileStream forceNewFileNamed: '/tmp/' , tmpFileName , '.out'.
	err := FileStream forceNewFileNamed: '/tmp/' , tmpFileName , '.err'.
	desc := Array
				with: nil
				with: out
				with: err.
	args := stringArgs.
	proc := UnixProcess
				forkJob: aString
				arguments: args
				environment: (Dictionary newFrom: {'LC_MESSAGES'-> 'C'})
				descriptors: desc]
		ensure: [out
				ifNotNilDo: [:o | o close].
			err
				ifNotNilDo: [:e | e close]].
	^ proc! !

!AbUtil class methodsFor: 'date and time' stamp: 'minami 3/15/2006 20:04'!
formattedDateString

"
	AbUtil formattedDateString
		>> '20050727'
"

	^ (Date today printFormat: #(3 2 1 $/ 1 1 2 ))
		copyReplaceAll: '/' with: ''! !

!AbUtil class methodsFor: 'date and time' stamp: 'minami 3/15/2006 20:05'!
formattedTimeString
"
	AbUtil formattedTimeString
"

	^ Time now print24 copyReplaceAll: ':' with: ''! !

!AbUtil class methodsFor: 'form' stamp: 'mu 10/5/2006 15:11'!
formFromFile: filePath
	^ ImageReadWriter
		formFromStream: (FileStream readOnlyFileNamed: filePath)! !

!AbUtil class methodsFor: 'form' stamp: 'mu 10/5/2006 17:47'!
formFromFile: filePath transparentColor: aColor
	| form |
	form := self formFromFile: filePath.
	^ form replaceColor: aColor withColor: Color transparent.
! !

!AbUtil class methodsFor: 'class initialization' stamp: 'mu 4/2/2006 17:10'!
initialize
	self initLocalAddressString! !

!AbUtil class methodsFor: 'class initialization' stamp: 'mu 4/2/2006 19:40'!
initLocalAddressString

	LocalAddressString _ nil! !

!AbUtil class methodsFor: 'testing' stamp: 'mu 5/16/2006 17:15'!
isDarwinMac
	^self isUnix and: [SmalltalkImage current osVersion beginsWith: 'darwin']
	! !

!AbUtil class methodsFor: 'testing' stamp: 'mu 6/12/2006 14:44'!
isMac
	"
	AbUtil isMa
	"
	FileDirectory pathNameDelimiter == $:
		ifTrue: [^ true].
	^ FileDirectory pathNameDelimiter == $/
		and: [SmalltalkImage current platformName = 'Mac OS']! !

!AbUtil class methodsFor: 'testing' stamp: 'minami 3/15/2006 20:05'!
isNumberString: aString 

	"AbUtil isNumberString: '12345' true"
	"AbUtil isNumberString: '123.45' true"
	"AbUtil isNumberString: '-123.45' true"
	"AbUtil isNumberString: '.12345' false"
	"AbUtil isNumberString: '-.12345' false"
	"AbUtil isNumberString: '12.34.5' false"
	"AbUtil isNumberString: '12345.' true"
	"AbUtil isNumberString: '123-45' false"
	"AbUtil isNumberString: '123a45' false"

	| numberString detection |
	aString isEmpty ifTrue: [^ false].
	numberString := aString.
	numberString first == $- ifTrue: [numberString := numberString allButFirst: 1].
	numberString first == $. ifTrue: [^ false].
	(numberString occurrencesOf: $.)
		> 1 ifTrue: [^ false].
	detection := numberString detect: [:character | ('1234567890.' includes: character) not]
				ifNone: [].
	^ detection isNil! !

!AbUtil class methodsFor: 'testing' stamp: 'mu 3/31/2006 12:29'!
isOsProcessInstalled
	^Smalltalk includesKey: #OSProcess! !

!AbUtil class methodsFor: 'testing' stamp: 'minami 3/15/2006 20:06'!
isUnix
"
	AbUtil isUnix
"
	^ FileDirectory pathNameDelimiter == $/! !

!AbUtil class methodsFor: 'testing' stamp: 'minami 3/15/2006 20:06'!
isWin
"
	AbUtil isWin
"
	^ FileDirectory pathNameDelimiter == $\! !

!AbUtil class methodsFor: 'networing' stamp: 'mu 5/16/2006 17:27'!
localAddressString
	"AbUtil localAddressString"
	LocalAddressString
		ifNil: [| addressStr | 
			addressStr _ self basicLocalAddressString.
			(NetNameResolver addressFromString: addressStr)
				ifNotNil: [LocalAddressString _ addressStr]].
	^ LocalAddressString! !

!AbUtil class methodsFor: 'networing' stamp: 'mu 11/23/2006 17:33'!
localAddressStringAskIfDetectionFailed
	"AbUtil localAddressStringAskIfDetectionFailed"
	| ip |
	ip := [self localAddressString]
				on: Error
				do: ['127.0.0.1'].
	ip = '127.0.0.1'
		ifTrue: [(FillInTheBlank request: 'Enter this host''s ip address:' initialAnswer: '192.168.xxx.yyy')
				ifNotEmptyDo: [:ans | ip := ans].
			(NetNameResolver addressFromString: ip asString)
				ifNil: [^ self localAddressStringAskIfDetectionFailed]
				ifNotNil: [LocalAddressString := ip]].
	^ ip! !

!AbUtil class methodsFor: 'networing' stamp: 'mu 11/23/2006 17:46'!
localAddressStringByIfConfig
	"AbUtil localAddressStringByIfConfig"

	| rawAnswer address |
	rawAnswer := self networkInterfaceName 
		ifEmpty: [self runUnixCommand: '/sbin/ifconfig' args: #()] 
		ifNotEmptyDo: [:ifName | 
			[self runUnixCommand: '/sbin/ifconfig' args: {ifName}] on: Error do: [:ex | ]].
	
	address := self extractAddressStringFrom: rawAnswer. 
	address
		ifEmpty: [address := NetNameResolver localAddressString].

	^ address
	

	! !

!AbUtil class methodsFor: 'networing' stamp: 'mu 11/23/2006 17:22'!
localHostName
	"AbUtil localHostName"
	| addressString resolved |
	addressString _ self localAddressStringAskIfDetectionFailed.

	resolved _ NetNameResolver
		nameForAddress: (NetNameResolver addressFromString: addressString)
		timeout: 5.

	^(resolved isNil or: [(NetNameResolver addressFromString: resolved) isNil])
		 ifTrue: [addressString]
		 ifFalse: [resolved]! !

!AbUtil class methodsFor: 'm17n' stamp: 'minami 3/23/2006 20:04'!
methodsWithWideString
"
	AbUtil methodsWithWideString
"

	SystemNavigation new
		browseAllSelect: [:method | method hasLiteralSuchThat: [:literal | literal class == WideString]]
		name: 'Methods with WideString'
		autoSelect: nil! !

!AbUtil class methodsFor: 'networing' stamp: 'mu 11/23/2006 17:46'!
networkInterfaceName
	"AbUtil networkInterfaceName"
	"Read myIF file to detect default binding network interface (just for unix)"

	| ifName str |
	ifName := ''.
	[[str := FileStream readOnlyFileNamed: 'myIF'.
	ifName := str contents]
		on: FileDoesNotExistException
		do: [:ex | ex]]
		ensure: [str	ifNotNilDo: [:s | s close]].
	^ifName withBlanksTrimmed
	! !

!AbUtil class methodsFor: 'serialize/deserialize' stamp: 'minami 3/15/2006 20:04'!
objectFromByteArray: aByteArray
"
	AbUtil objectFromByteArray: #(8 0 0 0 3 4 0 0 0 1 4 0 0 0 3 4 0 0 0 5) asByteArray
		>> #(1 3 5)
"

	| anObject refStream |
	refStream := ReferenceStream on: (RWBinaryOrTextStream with: aByteArray) reset.
	anObject := refStream next.
	refStream close.
	^ anObject! !

!AbUtil class methodsFor: 'serialize/deserialize' stamp: 'minami 3/15/2006 20:04'!
objectFromString: aString
"
	AbUtil objectFromString: 'CAAAAAMEAAAAAQQAAAADBAAAAAU='
		>> #(1 3 5)
"

	| byteStr oStr |
	byteStr := (Base64MimeConverter mimeDecodeToBytes: (ReadStream on: aString)).
	oStr := ReferenceStream on: byteStr.
	^oStr next! !

!AbUtil class methodsFor: 'ini' stamp: 'mu 4/19/2006 11:11'!
readConfigurationFromStream: stream 
	
	| lines settingDict |
	settingDict := Dictionary new.
	lines := OrderedCollection new.
	[[stream atEnd]
		whileFalse: [| line | 
			line := stream upTo: Character cr.
			line := line
						reject: [:character | character == Character lf].
			lines add: line]]
		ensure: [stream close].
	lines
		do: [:line | (line notEmpty
					and: [line first ~~ $;
							and: [line first ~~ $[]])
				ifTrue: [| readStream key value valueString | 
					readStream := ReadStream on: line.
					key := (readStream upTo: $=) withBlanksTrimmed asSymbol.
					valueString := readStream upToEnd withBlanksTrimmed.
					(#('true' 'false' 'nil' ) includes: valueString)
						ifTrue: [value := Compiler evaluate: valueString]
						ifFalse: [value := (AbUtil isNumberString: valueString)
										ifTrue: [valueString asNumber]
										ifFalse: [valueString]].
					settingDict at: key put: value]].
	^ settingDict! !

!AbUtil class methodsFor: 'ini' stamp: 'mu 4/19/2006 11:11'!
readConfigurationFrom: filename 
	"
	AbUtil readConfigurationFrom: 'sample.ini
	"
	| stream |
	(FileDirectory default fileExists: filename)
		ifFalse: [Transcript cr; show: '## Configuration file ' , filename printString , ' is not found. Use default configuration.'.
			^ Dictionary new].
	stream := CrLfFileStream readOnlyFileNamed: filename.
	^ self readConfigurationFromStream: stream! !

!AbUtil class methodsFor: 'networing' stamp: 'mu 11/23/2006 17:36'!
readLocalAddressString
	"AbUtil readLocalAddressString"
	"Just read a partial ifconfig output text file"

	| str address |
	address := ''.
	[[str := FileStream readOnlyFileNamed: 'myIP'.
	address := self extractAddressStringFrom: str contents]
		on: FileDoesNotExistException
		do: [:ex | ex]]
		ensure: [str	ifNotNilDo: [:s | s close]].
	address
		ifEmpty: [address := NetNameResolver localAddressString].
	^ address! !

!AbUtil class methodsFor: 'unix process' stamp: 'mu 3/31/2006 14:10'!
runUnixCommand: aString args: stringArgs 
	"self runUnixCommand: '/sbin/ifconfig' args: #('eth0')"
	"self runUnixCommand: '/bin/ls' args: #('-C' '/tmp')"
	| retry d proc |
	retry := 0.
	d := Delay forMilliseconds: 50.
	proc := self forkUnixCommand: aString args: stringArgs.
	proc
		ifNil: [self error: 'No OSProcess plugin in your VM'].
	[proc succeeded
		or: [retry > 5]]
		whileFalse: [d wait.
			retry := retry + 1.
			Processor yield].
	^ proc succeeded
		ifTrue: [proc initialStdOut contentsOfEntireFile]
		ifFalse: [self error: proc initialStdErr contentsOfEntireFile]! !

!AbUtil class methodsFor: 'image file' stamp: 'minami 3/15/2006 20:14'!
shortImageName
"
	AbUtil shortImageName
"
	^ FileDirectory
		localNameFor: (SmalltalkImage current fullNameForImageNamed: SmalltalkImage current imageName)! !

!AbUtil class methodsFor: 'serialize/deserialize' stamp: 'minami 3/15/2006 20:04'!
stringFromObject: anObject 
"
	AbUtil stringFromObject: #(1 3 5)
		>> 'CAAAAAMEAAAAAQQAAAADBAAAAAU='
"

	| file con |
	file := RWBinaryOrTextStream
				on: (ByteArray new: 5000).
	file binary.
	(ReferenceStream on: file)
		nextPut: anObject.
	con := Base64MimeConverter mimeEncode: file reset.
	file close.
	^ con contents! !

!Object methodsFor: '*ApplicationBase-debugging' stamp: 'mu 3/27/2006 17:46'!
crShow
	AbDebug current crShow: self asString! !

!Object methodsFor: '*ApplicationBase-debugging' stamp: 'MU 2/23/2006 17:56'!
displayForDebug
	self displayForDebug: 0@0! !

!Object methodsFor: '*ApplicationBase-debugging' stamp: 'mu 3/27/2006 16:46'!
displayForDebug: pointOrInteger
"
	self displayForDebug: 100@100
"
	| point message ctx |
	point := pointOrInteger isInteger 
				ifTrue: [Point x: 0 y: ((((pointOrInteger-1)*2)+1) * 10)] 
				ifFalse: [pointOrInteger].

	ctx _ thisContext sender asString.

	message _ String streamContents: [:s |
		s nextPutAll: point asString.
		s nextPutAll: (' - ' , Time now printString, ':', Time millisecondClockValue asString).
		s space.
		s nextPutAll: self asString.
		s nextPutAll: (' in ', ctx).
	].

	AbDebug current display: message at: point! !

!Object methodsFor: '*ApplicationBase-debugging' stamp: 'minami 3/23/2006 19:19'!
haltIfFalse
	^ self! !

!Object methodsFor: '*ApplicationBase-debugging' stamp: 'minami 3/23/2006 19:19'!
haltIfTrue
	^ self! !

!Object methodsFor: '*ApplicationBase-debugging' stamp: 'mu 3/27/2006 16:46'!
show
	AbDebug current show: self asString! !
AbDebug initialize!
AbInitializer initialize!
AbSettings initialize!
AbUtil initialize!
